@@ -76,6 +76,7 @@ def list(engine, single_thread, config, log_file_path, poll, debug):
         print(err)
         sys.exit(1)
 
+
 # Create Container Command
 @container.command()
 @click.option(
@@ -161,20 +162,32 @@ def create(
         print(err)
         sys.exit(1)
 
+
 # Delete Container Command
+@container.command()
 @click.option(
     "--container-name",
     required=True,
     help="Name of the self-service container.",
 )
 @click.option(
-    "--keep-vdbs",
-    help="\b\nIf set, deleting the container will not remove \n"
-    "the underlying virtual dataset(s)\n"
-    "[Default: False]",
+    "--delete-vdbs",
+    help="\b\nIf set, deleting the container will also delete \n"
+         "the underlying virtual dataset(s)\n"
+         "[Default: False]",
     default=False,
     is_flag=True,
 )
+@click.option(
+    "--keep-vdbs",
+    help="\b\n[DEPRECATION: This option will be deprecated with dxi-1.3.4 release]\n"
+        "If set, deleting the container will not remove \n"
+        "the underlying virtual dataset(s)\n"
+        "[Default: True]",
+    default=True,
+    is_flag=True,
+)
+
 @click.option(
     "--engine",
     default=DXIContainerConstants.ENGINE_ID,
@@ -210,9 +223,9 @@ def create(
     is_flag=True,
     default=False,
 )
-@container.command()
 def delete(
     container_name,
+    delete_vdbs,
     keep_vdbs,
     engine,
     single_thread,
@@ -234,12 +247,13 @@ def delete(
             debug=debug
         )
         boolean_based_system_exit(
-            ss_container.delete(container_name, keep_vdbs=keep_vdbs)
+            ss_container.delete(container_name, delete_vdbs, keep_vdbs=keep_vdbs)
         )
     except DXIException as err:
         print(err)
         sys.exit(1)
 
+
 # Reset Container Command
 @container.command()
 @click.option(
@@ -653,5 +667,147 @@ def remove_owner(
         print(err)
         sys.exit(1)
 
+
+# Enable Container Command
+@click.option(
+    "--container-name",
+    required=True,
+    help="Name of the self-service container.",
+)
+@click.option(
+    "--engine",
+    default=DXIContainerConstants.ENGINE_ID,
+    help="\b\nName of Delphix Engine in the config file.\n"
+    "[Default: default]",
+)
+@click.option(
+    "--config",
+    help="Full path to the dxtools.conf file with filename.",
+    default=DXIContainerConstants.CONFIG,
+)
+@click.option(
+    "--log-file-path",
+    help="Full path to the logs folder.",
+    default=DXIContainerConstants.LOG_FILE_PATH,
+)
+@click.option(
+    "--single-thread",
+    help="\b\nRun as a single thread\n"
+    "[Default: {}]".format(DXIContainerConstants.SINGLE_THREAD),
+    default=DXIContainerConstants.SINGLE_THREAD,
+    is_flag=True,
+)
+@click.option(
+    "--poll",
+    help="\b\nThe number of seconds to wait between job polls.\n"
+    "[Default: {}s]".format(DXIContainerConstants.POLL),
+    default=DXIContainerConstants.POLL,
+)
+@click.option(
+    "--debug",
+    help="Enable debug logging",
+    is_flag=True,
+    default=False,
+)
+@container.command()
+def enable(
+    container_name,
+    engine,
+    single_thread,
+    config,
+    log_file_path,
+    poll,
+    debug
+):
+    """
+    Enable a self-service container
+    """
+    try:
+        ss_container = DXIContainer(
+            engine=engine,
+            single_thread=single_thread,
+            config=config,
+            log_file_path=log_file_path,
+            poll=poll,
+            debug=debug
+        )
+        boolean_based_system_exit(
+            ss_container.enable(container_name)
+        )
+    except DXIException as err:
+        print(err)
+        sys.exit(1)
+
+# disable Container Command
+@click.option(
+    "--container-name",
+    required=True,
+    help="Name of the self-service container.",
+)
+@click.option(
+    "--engine",
+    default=DXIContainerConstants.ENGINE_ID,
+    help="\b\nName of Delphix Engine in the config file.\n"
+    "[Default: default]",
+)
+@click.option(
+    "--config",
+    help="Full path to the dxtools.conf file with filename.",
+    default=DXIContainerConstants.CONFIG,
+)
+@click.option(
+    "--log-file-path",
+    help="Full path to the logs folder.",
+    default=DXIContainerConstants.LOG_FILE_PATH,
+)
+@click.option(
+    "--single-thread",
+    help="\b\nRun as a single thread\n"
+    "[Default: {}]".format(DXIContainerConstants.SINGLE_THREAD),
+    default=DXIContainerConstants.SINGLE_THREAD,
+    is_flag=True,
+)
+@click.option(
+    "--poll",
+    help="\b\nThe number of seconds to wait between job polls.\n"
+    "[Default: {}s]".format(DXIContainerConstants.POLL),
+    default=DXIContainerConstants.POLL,
+)
+@click.option(
+    "--debug",
+    help="Enable debug logging",
+    is_flag=True,
+    default=False,
+)
+@container.command()
+def disable(
+    container_name,
+    engine,
+    single_thread,
+    config,
+    log_file_path,
+    poll,
+    debug
+):
+    """
+    Disable a self-service container
+    """
+    try:
+        ss_container = DXIContainer(
+            engine=engine,
+            single_thread=single_thread,
+            config=config,
+            log_file_path=log_file_path,
+            poll=poll,
+            debug=debug
+        )
+        boolean_based_system_exit(
+            ss_container.disable(container_name)
+        )
+    except DXIException as err:
+        print(err)
+        sys.exit(1)
+
+
 if __name__ == "__main__":
-    list()
+    delete()
