@@ -267,6 +267,7 @@ def find_obj_name(engine, f_class, obj_reference):
         exceptions.JobError,
         exceptions.HttpError,
     ) as err:
+        log.print_exception(err)
         raise dlpx_exceptions.DlpxException(err)
 
 
@@ -311,6 +312,8 @@ def find_db_repo(engine, install_type, f_environment_ref, f_install_path, instal
                 else:
                     return None
         else:
+            log.print_exception(f'Only OracleInstall, AppDataRepository or MSSqlInstance '
+                                f'types are supported.\n')
             raise dlpx_exceptions.DlpxException(
                 f"Only OracleInstall, AppDataRepository or MSSqlInstance "
                 f"types are supported.\n"
@@ -411,6 +414,7 @@ def build_data_source_params(dlpx_obj, obj, data_source):
         ds_params.container = db_obj.reference
         return ds_params
     except exceptions.RequestError as err:
+        log.print_exception(f"\nCould not find {data_source}\n{err}")
         raise dlpx_exceptions.DlpxObjectNotFound(
             f"\nCould not find {data_source}\n{err}"
         )
@@ -427,6 +431,7 @@ def find_all_objects(engine, f_class):
     try:
         return f_class.get_all(engine)
     except (exceptions.JobError, exceptions.HttpError) as err:
+        log.print_exception(f"{engine.address} Error encountered in {f_class}: {err}\n")
         raise dlpx_exceptions.DlpxException(
             f"{engine.address} Error encountered in {f_class}: {err}\n"
         )
@@ -448,11 +453,12 @@ def find_branch_by_name_and_container_ref(engine,branch_name, container_ref):
                 return branch
         raise Exception
     except Exception as err:
+        log.print_exception(f"Could not find branch:{branch_name}"
+                            f" in container with ref: {container_ref}")
         raise dlpx_exceptions.DlpxObjectNotFound(f" Could not find branch:{branch_name}"
                                                  f" in container with ref: {container_ref}")
 
 
-
 def find_obj_list(obj_lst, obj_name):
     """
     Function to find an object in a list of objects
@@ -467,6 +473,7 @@ def find_obj_list(obj_lst, obj_name):
             return obj
     raise dlpx_exceptions.DlpxObjectNotFound(f"Did not find {obj_name}\n")
 
+
 def find_obj_list_by_containername(obj_lst, container_name):
     """
     Function to find an object in a list of objects
@@ -510,6 +517,7 @@ def find_all_snapshots(engine_session, container_ref, timeflow_ref=None, from_da
         )
         return snapshots
     except Exception as err:
+        log.print_exception(f"There was an error retrieving snapshot for the specified timestamp.{err}")
         raise Exception(f"There was an error retrieving snapshot for the specified timestamp.{err}")
 
 def find_snapshot_by_timestamp(engine_session, container_ref, timestamp):
@@ -575,4 +583,5 @@ def find_db_timezone(engine_session, container_ref):
             break
         return db_tz
     except Exception as err:
+        log.print_exception(f"Unable to find the database timezone:{err}")
         raise Exception(f"Unable to find the database timezone:{err}")
