@@ -13,6 +13,7 @@ from delphixpy.v1_10_2.web import selfservice
 from delphixpy.v1_10_2.web import vo
 from dxi._lib import dlpx_exceptions as dxe
 from dxi._lib import dx_logging as log
+from dxi._lib import dxi_constants as const
 from dxi._lib import get_references as ref
 from dxi._lib import run_job
 from dxi._lib.dxi_constants import BookmarkOps
@@ -123,10 +124,11 @@ class DXIBookmark(DXIBase):
         """
         self.action = BookmarkOps.LIST
         self.tags = tags
+        self.bm_list = []
         try:
             log.print_info(f"Running dxi bookmark list.")
             self._execute_operation(self._list_bookmark_helper)
-            return True
+            return self.bm_list
         except Exception:
             return False
 
@@ -321,16 +323,17 @@ class DXIBookmark(DXIBase):
                                         branch_name,
                                         ss_bookmark.bookmark_type,
                                         data_layout,
-                                        tag,
+                                        ",".join(tag for tag in ss_bookmark.tags),
                                     ],
                                 )
                             )
                         )
+                self.bm_list = display_list
                 print(
                     tabulate(
                         display_list,
                         headers=BookmarkConstants.LIST_HEADER,
-                        tablefmt="github",
+                        tablefmt=const.FORMAT_GITHUB,
                     )
                 )
             return bookmark_list
@@ -340,7 +343,7 @@ class DXIBookmark(DXIBase):
             exceptions.RequestError,
         ) as err:
             log.print_exception(
-                f"ERROR: The bookmarks could not be" f"listed. ERROR: {err}"
+                f"ERROR: The bookmarks could not be listed. ERROR: {err}"
             )
 
     @run_async
