@@ -24,6 +24,7 @@ from dxi._lib import get_references
 from dxi._lib import run_job
 from dxi._lib.dxi_constants import BranchOps
 from dxi._lib.run_async import run_async
+from dxi._lib.util import DXIConfigConstantsHelper
 from dxi.dxi_tool_base import DXIBase
 from tabulate import tabulate
 
@@ -35,8 +36,8 @@ class DXIBranchConstants(object):
 
     SINGLE_THREAD = False
     POLL = 20
-    CONFIG = "../../dxi-data/config/dxtools.conf"
-    LOG_FILE_PATH = "../../dxi-data/logs/"
+    CONFIG = DXIConfigConstantsHelper().get_config()
+    LOG_FILE_PATH = DXIConfigConstantsHelper().get_logdir()
     ENGINE_ID = "default"
     PARALLEL = 5
     TYPE = None
@@ -104,10 +105,11 @@ class DXIBranch(DXIBase):
         List all existing branches
         """
         self.action = BranchOps.LIST
+        self.branch_list = []
         try:
             dx_logging.print_debug("Listing Branches")
             self._execute_operation(self._list_branch_helper)
-            return True
+            return self.branch_list
         except Exception:
             return False
 
@@ -361,6 +363,7 @@ class DXIBranch(DXIBase):
                     poll=self.poll,
                     failures=self.failures,
                 )
+                self.branch_list = print_list
                 print("\n")
                 print(
                     tabulate(
