@@ -10,6 +10,7 @@ import json
 from dxi._lib import dlpx_exceptions as dxe
 from dxi._lib import dx_logging as log
 from dxi._lib import util
+from dxi._lib.util import DXIConfigConstantsHelper
 
 
 class DXIConfigConstants(object):
@@ -17,8 +18,8 @@ class DXIConfigConstants(object):
     Define constants for Config Operations.
     """
 
-    CONFIG = "../../dxi-data/config/dxtools.conf"
-    LOG_DIR = "../../dxi-data/logs/"
+    CONFIG = DXIConfigConstantsHelper().get_config()
+    LOG_DIR = DXIConfigConstantsHelper().get_logdir()
     MODULE_NAME = __name__
 
 
