@@ -51,13 +51,6 @@ class _ProvisionVDBMixin(object):
         )
         engine_name = list(dlpx_obj.dlpx_ddps)[0]
         dxtf_obj = dxtf.DxTimeflow(dlpx_obj.server_session)
-        try:
-            vdb_obj = ref.find_obj_by_name(
-                dlpx_obj.server_session, database, self.name
-            )
-            raise dxe.DlpxObjectExists(f"{vdb_obj} exists.")
-        except dxe.DlpxObjectNotFound:
-            pass
         vdb_params = vo.ASEProvisionParameters()
         vdb_params.container = vo.ASEDBContainer()
         if self.no_truncate_log:
@@ -96,13 +89,6 @@ class _ProvisionVDBMixin(object):
         )
         engine_name = list(dlpx_obj.dlpx_ddps)[0]
         timeflow_obj = dxtf.DxTimeflow(dlpx_obj.server_session)
-        try:
-            vdb_obj = ref.find_obj_by_name(
-                dlpx_obj.server_session, database, self.name
-            )
-            raise dxe.DlpxObjectExists(f"{vdb_obj} exists.")
-        except dxe.DlpxObjectNotFound:
-            pass
         vdb_params = vo.MSSqlProvisionParameters()
         vdb_params.container = vo.MSSqlDatabaseContainer()
         vdb_params.container.group = group_ref
@@ -142,13 +128,6 @@ class _ProvisionVDBMixin(object):
             dlpx_obj
         )
         timeflow_obj = dxtf.DxTimeflow(dlpx_obj.server_session)
-        try:
-            vdb_obj = ref.find_obj_by_name(
-                dlpx_obj.server_session, database, self.name
-            )
-            raise dxe.DlpxObjectExists(f"{vdb_obj} exists.")
-        except dxe.DlpxObjectNotFound:
-            pass
         vfiles_params = vo.AppDataProvisionParameters()
         vfiles_params.source = vo.AppDataVirtualSource()
         vfiles_params.source_config = vo.AppDataDirectSourceConfig()
@@ -230,13 +209,6 @@ class _ProvisionVDBMixin(object):
             dlpx_obj
         )
         engine_name = list(dlpx_obj.dlpx_ddps)[0]
-        try:
-            vdb_obj = ref.find_obj_by_name(  # noqa
-                dlpx_obj.server_session, database, self.name
-            )
-            raise dxe.DlpxObjectExists(f"{self.name} exists.")
-        except dxe.DlpxObjectNotFound:
-            pass
         vdb_params = vo.OracleProvisionParameters()
         vdb_params.open_resetlogs = True
         vdb_params.container = vo.OracleDatabaseContainer()
@@ -292,13 +264,6 @@ class _ProvisionVDBMixin(object):
         )
         vdb_name = self.name
         engine_name = list(dlpx_obj.dlpx_ddps)[0]
-        try:
-            vdb_obj = ref.find_obj_by_name(
-                dlpx_obj.server_session, database, vdb_name
-            )
-            raise dxe.DlpxObjectExists(f"{vdb_obj} exists.")
-        except dxe.DlpxObjectNotFound:
-            pass
         vdb_params = vo.OracleMultitenantProvisionParameters()
         vdb_params.open_resetlogs = True
         vdb_params.container = vo.OracleDatabaseContainer()
@@ -424,13 +389,6 @@ class _ProvisionVDBMixin(object):
         )
         vdb_name = self.name
         engine_name = list(dlpx_obj.dlpx_ddps)[0]
-        try:
-            vdb_obj = ref.find_obj_by_name(
-                dlpx_obj.server_session, database, vdb_name
-            )
-            raise dxe.DlpxObjectExists(f"{vdb_obj} exists.")
-        except dxe.DlpxObjectNotFound:
-            pass
         vdb_params = vo.OracleMultitenantProvisionParameters()
         vdb_params.open_resetlogs = True
         vdb_params.container = vo.OracleDatabaseContainer()
@@ -484,13 +442,6 @@ class _ProvisionVDBMixin(object):
             dlpx_obj
         )
         engine_name = list(dlpx_obj.dlpx_ddps)[0]
-        try:
-            vdb_obj = ref.find_obj_by_name(
-                dlpx_obj.server_session, database, self.name
-            )
-            raise dxe.DlpxObjectExists(f"{vdb_obj} exists.")
-        except dxe.DlpxObjectNotFound:
-            pass
         vdb_params = vo.OracleProvisionParameters()
         vdb_params.open_resetlogs = True
         vdb_params.container = vo.OracleDatabaseContainer()
@@ -541,13 +492,6 @@ class _ProvisionVDBMixin(object):
         group_ref, environment_obj, source_obj = self._find_group_source_environment_data(  # noqa
             dlpx_obj
         )
-        try:
-            vdb_obj = ref.find_obj_by_name(
-                dlpx_obj.server_session, database, self.name
-            )
-            raise dxe.DlpxObjectExists(f"{vdb_obj} exists.")
-        except dxe.DlpxObjectNotFound:
-            pass
         vdb_params = vo.AppDataProvisionParameters()
         vdb_params.container = vo.AppDataContainer()
         vdb_params.container.group = group_ref
