@@ -11,8 +11,9 @@ from dxi._cli._database_cli import database
 from dxi._cli._environment_cli import environment
 from dxi._cli._snapshot_cli import snapshot
 from dxi._cli._template_cli import template
-
-__version__ = "1.3.0"
+from dxi._cli._group_cli import group
+from dxi._cli._user_cli import user
+from dxi._version import __version__
 
 
 @click.group()
@@ -48,5 +49,11 @@ dxi.add_command(template)
 # Adding config as sub-group-command of dxi
 dxi.add_command(config)
 
+# Adding group as sub-group-command of dxi
+dxi.add_command(group)
+
+# Adding user as sub-group-command of dxi
+dxi.add_command(user)
+
 if __name__ == "__main__":
     dxi()
